# Tir contributors
This list of contributors is sorted alphabetically

* [kvfi](https://github.com/kvfi/t)
    - Author and maintainer
* [Zouhir Sarrar](https://github.com/ZouhirSarrar)
    - Testing and QA